pub enum Entry<'a, I, T, SA: Allocator = Global, DA: Allocator = Global> {
Vacant(VacantEntry<'a, I, T, SA, DA>),
Occupied(OccupiedEntry<'a, I, T, SA, DA>),
}Expand description
A view into a single entry in a sparse set, which may be either vacant or occupied.
This is constructed from the SparseSet::entry function.
Variants
Vacant(VacantEntry<'a, I, T, SA, DA>)
A vacant entry.
Occupied(OccupiedEntry<'a, I, T, SA, DA>)
An occupied entry.
Implementations
Sourceimpl<'a, I: SparseSetIndex, T, SA: Allocator, DA: Allocator> Entry<'a, I, T, SA, DA>
impl<'a, I: SparseSetIndex, T, SA: Allocator, DA: Allocator> Entry<'a, I, T, SA, DA>
Sourcepub fn and_modify<F: FnOnce(&mut T)>(self, function: F) -> Self
pub fn and_modify<F: FnOnce(&mut T)>(self, function: F) -> Self
Provides in-place mutable access to an occupied entry before any potential inserts into the sparse set.
Sourcepub fn entry_index(&self) -> I
pub fn entry_index(&self) -> I
The index used to create this entry.
Sourcepub fn or_insert(self, default: T) -> &'a mut T
pub fn or_insert(self, default: T) -> &'a mut T
Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.
Sourcepub fn or_insert_with<F: FnOnce() -> T>(self, default: F) -> &'a mut T
pub fn or_insert_with<F: FnOnce() -> T>(self, default: F) -> &'a mut T
Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.
Sourcepub fn insert_entry(self, value: T) -> OccupiedEntry<'a, I, T, SA, DA>
pub fn insert_entry(self, value: T) -> OccupiedEntry<'a, I, T, SA, DA>
Sets the value of the entry, and returns an OccupiedEntry.